@@ -1,6 +1,6 @@
 package Opsview::REST::APICaller;
 {
-  $Opsview::REST::APICaller::VERSION = '0.004';
+  $Opsview::REST::APICaller::VERSION = '0.005';
 }
 
 use Moose::Role;
@@ -62,6 +62,18 @@ sub post {
     return $self->json->decode($r->{content});
 }
 
+sub put {
+    my ($self, $method, $data) = @_;
+
+    my $stuff = { headers => $self->headers };
+    $stuff->{content} = $self->json->encode($data) if defined $data;
+
+    my $r = $self->ua->put($self->base_url . $method, $stuff);
+    croak $self->_errmsg($r) unless $r->{success};
+
+    return $self->json->decode($r->{content});
+}
+
 sub _errmsg {
     my ($self, $r) = @_;
     my $cont; $cont = $self->json->decode($r->{content})
